@@ -41,23 +41,3 @@ def undigattr(obj, attr, value, default=None):
         if callable(obj):
             obj = obj()
     setattr(obj, last, value)
-
-from django.db.models import Model
-
-
-class JSONEncoder(json.JSONEncoder):
-    '''
-    Same features as JSONEncoder, but not as a generator.
-    '''
-    def default(self, obj):
-        if isinstance(obj, Decimal):
-            return str(obj)
-        if isinstance(obj, datetime.datetime):
-            return obj.replace(microsecond=0).isoformat(' ')
-        if isinstance(obj, datetime.date):
-            return obj.isoformat()
-        if hasattr(obj, '__iter__'):
-            return list(obj)
-        if isinstance(obj, Model):
-            return unicode(obj)
-        return super(JSONEncoder, self).default(obj)
